@@ -1,5 +1,5 @@
 /*
-	libmpg123: MPEG Audio Decoder library (version 1.6.4)
+	libmpg123: MPEG Audio Decoder library (version 1.7.3)
 
 	copyright 1995-2008 by the mpg123 project - free software under the terms of the LGPL 2.1
 	see COPYING and AUTHORS files in distribution or http://mpg123.org
@@ -137,6 +137,7 @@ enum mpg123_param_flags
 	,MPG123_NO_RESYNC    = 0x80 /**< 10000000 Disable resync stream after error.                             */
 	,MPG123_SEEKBUFFER   = 0x100 /**< 000100000000 Enable small buffer on non-seekable streams to allow some peek-ahead (for better MPEG sync). */
 	,MPG123_FUZZY        = 0x200 /**< 001000000000 Enable fuzzy seeks (guessing byte offsets or using approximate seek points from Xing TOC) */
+	,MPG123_FORCE_FLOAT  = 0x400 /**< 010000000000 Force floating point output (32 or 64 bits depends on mpg123 internal precision). */
 };
 
 /** choices for MPG123_RVA */
@@ -216,7 +217,9 @@ enum mpg123_errors
 	MPG123_NULL_POINTER, /**< You gave a null pointer somewhere where you shouldn't have. */
 	MPG123_BAD_KEY,	/**< Bad key value given. */
 	MPG123_NO_INDEX,	/**< No frame index in this build. */
-	MPG123_INDEX_FAIL	/**< Something with frame index went wrong. */
+	MPG123_INDEX_FAIL,	/**< Something with frame index went wrong. */
+	MPG123_BAD_DECODER_SETUP,	/**< Something prevents a proper decoder setup */
+	MPG123_MISSING_FEATURE  /**< This feature has not been built into libmpg123. */
 };
 
 /** Return a string describing that error errcode means. */
@@ -243,14 +246,21 @@ EXPORT int mpg123_errcode(mpg123_handle *mh);
  */
 
 /** Return a NULL-terminated array of generally available decoder names (plain 8bit ASCII). */
-EXPORT char **mpg123_decoders();
+EXPORT const char **mpg123_decoders();
 
 /** Return a NULL-terminated array of the decoders supported by the CPU (plain 8bit ASCII). */
-EXPORT char **mpg123_supported_decoders();
+EXPORT const char **mpg123_supported_decoders();
 
 /** Set the chosen decoder to 'decoder_name' */
 EXPORT int mpg123_decoder(mpg123_handle *mh, const char* decoder_name);
 
+/** Get the currently active decoder engine name.
+    The active decoder engine can vary depening on output constraints,
+    mostly non-resampling, integer output is accelerated via 3DNow & Co. but for other modes a fallback engine kicks in.
+    Note that this can return a decoder that is ony active in the hidden and not available as decoder choice from the outside.
+    \return The decoder name or NULL on error. */
+EXPORT const char* mpg123_current_decoder(mpg123_handle *mh);
+
 /*@}*/
 
 
@@ -261,28 +271,39 @@ EXPORT int mpg123_decoder(mpg123_handle *mh, const char* decoder_name);
  * @{
  */
 
-/** 16 or 8 bits, signed or unsigned... all flags fit into 15 bits and are designed to have meaningful binary AND/OR.
- * Adding float and 32bit int definitions for experimental fun. Only 32bit (and possibly 64bit) float is
- * somewhat there with a dedicated library build. */
+/** An enum over all sample types possibly known to mpg123.
+ *  The values are designed as bit flags to allow bitmasking for encoding families.
+ *
+ *  Note that (your build of) libmpg123 does not necessarily support all these.
+ *  Usually, you can expect the 8bit encodings and signed 16 bit.
+ *  Also 32bit float will be usual beginning with mpg123-1.7.0 .
+ *  What you should bear in mind is that (SSE, etc) optimized routines are just for
+ *  signed 16bit (and 8bit derived from that). Other formats use plain C code.
+ *
+ *  All formats are in native byte order. On a little endian machine this should mean
+ *  that you can just feed the MPG123_ENC_SIGNED_32 data to common 24bit hardware that
+ *  ignores the lowest byte (or you could choose to do rounding with these lower bits).
+ */
 enum mpg123_enc_enum
 {
 	 MPG123_ENC_8      = 0x00f  /**< 0000 0000 1111 Some 8 bit  integer encoding. */ 
 	,MPG123_ENC_16     = 0x040  /**< 0000 0100 0000 Some 16 bit integer encoding. */
 	,MPG123_ENC_32     = 0x100  /**< 0001 0000 0000 Some 32 bit integer encoding. */
 	,MPG123_ENC_SIGNED = 0x080  /**< 0000 1000 0000 Some signed integer encoding. */
-	,MPG123_ENC_FLOAT  = 0x800  /**< 1110 0000 0000 Some float encoding. */
-	,MPG123_ENC_SIGNED_16   = (MPG123_ENC_16|MPG123_ENC_SIGNED|0x10) /**< 0000 1101 0000 signed 16 bit */
-	,MPG123_ENC_UNSIGNED_16 = (MPG123_ENC_16|0x20)                   /**< 0000 0110 0000 unsigned 16 bit*/
-	,MPG123_ENC_UNSIGNED_8  = 0x01                                   /**< 0000 0000 0001 unsigned 8 bit*/
-	,MPG123_ENC_SIGNED_8    = (MPG123_ENC_SIGNED|0x02)               /**< 0000 1000 0010 signed 8 bit*/
-	,MPG123_ENC_ULAW_8      = 0x04                                   /**< 0000 0000 0100 ulaw 8 bit*/
-	,MPG123_ENC_ALAW_8      = 0x08                                   /**< 0000 0000 1000 alaw 8 bit */
-	,MPG123_ENC_SIGNED_32   = MPG123_ENC_32|MPG123_ENC_SIGNED|0x10   /**< 0001 1001 0000 signed 32 bit */
-	,MPG123_ENC_UNSIGNED_32 = MPG123_ENC_32|0x20                     /**< 0001 0010 0000 unsigned 32 bit */
-	,MPG123_ENC_FLOAT_32    = 0x200                                  /**< 0010 0000 0000 32bit float */
-	,MPG123_ENC_FLOAT_64    = 0x400                                  /**< 0100 0000 0000 64bit float */
+	,MPG123_ENC_FLOAT  = 0xe00  /**< 1110 0000 0000 Some float encoding. */
+	,MPG123_ENC_SIGNED_16   = (MPG123_ENC_16|MPG123_ENC_SIGNED|0x10) /**<           1101 0000 signed 16 bit */
+	,MPG123_ENC_UNSIGNED_16 = (MPG123_ENC_16|0x20)                   /**<           0110 0000 unsigned 16 bit */
+	,MPG123_ENC_UNSIGNED_8  = 0x01                                   /**<           0000 0001 unsigned 8 bit */
+	,MPG123_ENC_SIGNED_8    = (MPG123_ENC_SIGNED|0x02)               /**<           1000 0010 signed 8 bit */
+	,MPG123_ENC_ULAW_8      = 0x04                                   /**<           0000 0100 ulaw 8 bit */
+	,MPG123_ENC_ALAW_8      = 0x08                                   /**<           0000 1000 alaw 8 bit */
+	,MPG123_ENC_SIGNED_32   = MPG123_ENC_32|MPG123_ENC_SIGNED|0x1000 /**< 0001 0001 1000 0000 signed 32 bit */
+	,MPG123_ENC_UNSIGNED_32 = MPG123_ENC_32|0x2000                   /**< 0010 0001 0000 0000 unsigned 32 bit */
+	,MPG123_ENC_FLOAT_32    = 0x200                                  /**<      0010 0000 0000 32bit float */
+	,MPG123_ENC_FLOAT_64    = 0x400                                  /**<      0100 0000 0000 64bit float */
 	,MPG123_ENC_ANY = ( MPG123_ENC_SIGNED_16  | MPG123_ENC_UNSIGNED_16 | MPG123_ENC_UNSIGNED_8 
 	                  | MPG123_ENC_SIGNED_8   | MPG123_ENC_ULAW_8      | MPG123_ENC_ALAW_8
+	                  | MPG123_ENC_SIGNED_32  | MPG123_ENC_UNSIGNED_32
 	                  | MPG123_ENC_FLOAT_32   | MPG123_ENC_FLOAT_64 ) /**< any encoding */
 };
 
@@ -681,7 +702,7 @@ EXPORT int  mpg123_set_substring(mpg123_string *sb, const char *stuff, size_t fr
 
 /** Sub data structure for ID3v2, for storing various text fields (including comments).
  *  This is for ID3v2 COMM, TXXX and all the other text fields.
- *  Only COMM and TXXX have a description, only COMM has a language.
+ *  Only COMM and TXXX have a description, only COMM and USLT have a language.
  *  You should consult the ID3v2 specification for the use of the various text fields ("frames" in ID3v2 documentation, I use "fields" here to separate from MPEG frames). */
 typedef struct
 {
@@ -709,7 +730,7 @@ typedef struct
 	   There can be multiple occurences, the pointers above always point to the last encountered data. */
 	mpg123_text    *comment_list; /**< Array of comments. */
 	size_t          comments;     /**< Number of comments. */
-	mpg123_text    *text;         /**< Array of ID3v2 text fields */
+	mpg123_text    *text;         /**< Array of ID3v2 text fields (including USLT) */
 	size_t          texts;        /**< Numer of text fields. */
 	mpg123_text    *extra;        /**< The array of extra (TXXX) fields. */
 	size_t          extras;       /**< Number of extra text (TXXX) fields. */
